package main

import (
	"flag"
	"fmt"
	"log"
	"net/http"
	"os"

	"github.com/elazarl/goproxy"
)

var f *os.File

type Logger struct{}

func (l *Logger) Printf(format string, v ...interface{}) {
	log.Printf(format, v...)
}

func initLog() {
	var err error
	f, err = os.OpenFile("log.txt", os.O_APPEND|os.O_CREATE|os.O_WRONLY, 0644)
	if err != nil {
		log.Fatal(err)
	}

	log.SetOutput(f)
}

func main() {
	initLog()
	defer func() {
		if f != nil {
			f.Close()
		}
	}()

	var port = flag.String("p", "7080", "代理端口")
	flag.Parse()
	log.Println(fmt.Sprintf("开始监听 %s:%s", "127.0.0.1", *port))

	proxy := goproxy.NewProxyHttpServer()
	proxy.Logger = new(Logger)

	// proxy.OnRequest(goproxy.ReqHostMatches(regexp.MustCompile(".*:443$"))).DoFunc(func(r *http.Request, ctx *goproxy.ProxyCtx) (*http.Request, *http.Response) {
	// 	log.Println("==========================")
	// 	log.Println(fmt.Sprintf("==========[%s] %s", r.Method, r.RequestURI))

	// 	return r, nil
	// })

	proxy.Verbose = true
	log.Fatal(http.ListenAndServe(":"+*port, proxy))
}
